use 5.16.0;
use warnings;

our $VERSION = '0.2205'; # VERSION
# PODNAME: Map::Metro::Standard

package Map::Metro::Standard {

    use Syntax::Collector q/
        use feature 0 ':5.16';
        use warnings 0;
        use true 0;
    /;
}

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Map::Metro::Standard

=head1 VERSION

Version 0.2205, released 2015-01-19.

=head1 SOURCE

L<https://github.com/Csson/p5-Map-Metro>

=head1 HOMEPAGE

L<https://metacpan.org/release/Map-Metro>

=head1 AUTHOR

Erik Carlsson <info@code301.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by Erik Carlsson.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
